<?php
/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// +-----------------------------------------------------------+
// | PHP version 4                                             |
// +-----------------------------------------------------------+
// | Copyright (c) Trond K. Pettersen @ http://lingo.uib.no    |
// | Any script (c) Lingo is subject to the GNU/GPL license.   |
// +-----------------------------------------------------------+
// | These scripts require that the PEAR base directory is in  |
// | your include_path. PEAR::DB is subject to the PHP license.|
// | See http://pear.php.net for help or more info on PEAR.    |
// +-----------------------------------------------------------+

// Check to ensure that script is not called "individually".
if(!defined('MOO2DB')) {
  header("HTTP/1.1 403 Forbidden");
  exit("<h1>403 Forbidden</h1>");
}

$upload_folder = $config['upload_folder'];

class File
{

  // _______________ "Static" methods _______________ \\ 
  
  
  /****** various methods used with usort() for sorting of file objects ******/
  
  function cmp($a, $b) {
    if($a == $b) {
      return 0;
    }
    return ($a < $b) ? -1 : 1; 
  }
  
  function sort_size($fa, $fb) {
    return File::cmp(filesize($fa->path), filesize($fb->path));
  }

  function sort_modified($fa, $fb) {
    // Note that we let the args swith place to sort by last modified
    return File::cmp($fa->get_modified(), $fb->get_modified());
  } 

  function sort_filename($fa, $fb) {
    return strcasecmp($fa->get_filename(), $fb->get_filename());
  }
  
  function sort_size_desc($fa, $fb) {
    return -File::sort_size($fa, $fb);
  }

  function sort_modified_desc($fa, $fb) {
    // Note that we let the args swith place to sort by last modified
    return -File::sort_modified($fa, $fb);
  } 
  
  function sort_filename_desc($fa, $fb) {
    return -File::sort_filename($fa, $fb);
  }


  /****** various methods used with usort() for sorting of file objects ******/
  
  
  /**
       * @param string file name
       * @return true if valid file name, else false 
       */
  function is_valid_filename($filename)
  {
    // As much as we would like to accept all unicode characters,
    // to implement such is hell as the end users' web browsers 
    // play an important role (or the role) in interpreting URLs and sending requests.
    // NO, we don't want to use PHP4.x + regex for this...
    $chars = array('a','b','c','d','e','f','g','h','i','j','k','l',
                   'm','n','o','p','q','r','s','t','u','v','w','x','y','z',
                   'A','B','C','D','E','F','G','H','I','J','K','L','M','N','O',
                   'P','Q','R','S','T','U','V','W','X','Y','Z',
                   '0','1','2','3','4','5','6','7','8','9','.','-','_');
    $ch_fname = explode("\n", trim(chunk_split($filename, 1))); // trim: Remove the last \r\n
    foreach($ch_fname as $chr) {
        if(!in_array(trim($chr), $chars)) { // Make sure it's just the one char
        return false;
      }
    }
    return true;
  }
  
  
  /** 
       * @param string file name
       * @return true if valid file extension, else false 
       */
  function is_valid_filetype($filename)
  {
    global $config;
    $ext_start = strrpos($filename, '.');
    if($ext_start === false) {
      return false;
    }
    $ext = substr($filename, $ext_start+1);
    
    // Only whitelisted file types are, and should be, allowed
    return in_array(strtolower($ext), $config['file_extensions']);
  }
  
  
  /** 
       * @param size int
       * @return human friendly file size 
       */
  function get_file_size($size=0)
  {
    if($size == 0) {
      return '0 Bytes';
    }
    
    if($size < 0) {
      $size = -$size;
    }
    
    // Source: http://no2.php.net/manual/en/function.filesize.php
    $filesizename = array(" Bytes", " KB", " MB", " GB", 
                          " TB", " PB", " EB", " ZB", " YB");
    @$filesize = ((string) round($size/pow(1024, ($i = floor(log($size, 1024)))), 2)) . 
                $filesizename[$i];
    
    return $filesize;

  }
  
  
  

  // _______________ Member vars _______________ \\
  
  
  // Public
  var $user_nr;  // String user_nr
  var $path;    // String absolute path to file

  // _______________ Methods _______________ \\

  /** Constuctor */
  function File($path,$un) 
  {
    $this->path = $path;
    $this->user_nr = $un;
  }
  
  
  /** @return string abs. path to file */  
  function get_path()
  {
    return $this->path;
  }
  
  
  /** @return string basename */  
  function get_filename()
  {
    return basename($this->path);
  }
  
  
  /** @return string relative (to script) url */
  function get_url()
  {
    global $upload_folder;
    return $upload_folder . '/' . $this->user_nr . '/' . $this->get_filename();
  }
  
  /** @return string date last modified */
  function get_modified($format=' m-d-Y H:i:s')
  {
    return date($format, filemtime($this->path));
  }
  
  /** @return string human readable file size */
  function get_size()
  {
    return File::get_file_size(filesize($this->path));
  }
  
}

?>